R/scale_fill_discrete_phs.R
scale_fill_discrete_phs.RdThe default discrete colour filling scale for use in PHS
scale_fill_discrete_phs(
...,
type = "seq",
palette = 1,
direction = 1,
aesthetics = "fill"
)Additional parameters passed on to the scale type
either "seq" (sequential) or "qual" (qualitative).
Defaulted as "seq". Please see phs_palette_types for more details.
a number describing which palette to use within that type.
Defaulted as 1 referring to the first palette "main-purples" in type "seq".
It can also be the actual name of the palette e.g. main-purples.
Please see phs_palettes for more details.
either be 1 (following the palette order) or -1 (reversing the palette order). Defaulted as 1.
defaulted as "fill"
There are a list of discrete colour filling scales that can be used for PHS charts, such as main-purples which contains phs-purple, phs-purple-80, phs-purple-50, phs-purple-30 and phs-purple-10.